==> servicediscovery-1.60.0-sources.jar: software/amazon/awscdk/services/servicediscovery/PrivateDnsNamespaceAttributes.java <==
package software.amazon.awscdk.services.servicediscovery;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.799Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicediscovery.$Module.class, fqn = "@aws-cdk/aws-servicediscovery.PrivateDnsNamespaceAttributes")
@software.amazon.jsii.Jsii.Proxy(PrivateDnsNamespaceAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface PrivateDnsNamespaceAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * Namespace ARN for the Namespace.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNamespaceArn();

    /**
     * Namespace Id for the Namespace.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNamespaceId();

    /**
     * A name for the Namespace.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNamespaceName();

    /**
     * @return a {@link Builder} of {@link PrivateDnsNamespaceAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PrivateDnsNamespaceAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<PrivateDnsNamespaceAttributes> {
        private java.lang.String namespaceArn;
        private java.lang.String namespaceId;
        private java.lang.String namespaceName;

        /**
         * Sets the value of {@link PrivateDnsNamespaceAttributes#getNamespaceArn}
         * @param namespaceArn Namespace ARN for the Namespace. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder namespaceArn(java.lang.String namespaceArn) {
            this.namespaceArn = namespaceArn;
            return this;
        }

        /**
         * Sets the value of {@link PrivateDnsNamespaceAttributes#getNamespaceId}
         * @param namespaceId Namespace Id for the Namespace. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder namespaceId(java.lang.String namespaceId) {
            this.namespaceId = namespaceId;
            return this;
        }

        /**
         * Sets the value of {@link PrivateDnsNamespaceAttributes#getNamespaceName}
         * @param namespaceName A name for the Namespace. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder namespaceName(java.lang.String namespaceName) {
            this.namespaceName = namespaceName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PrivateDnsNamespaceAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public PrivateDnsNamespaceAttributes build() {
            return new Jsii$Proxy(namespaceArn, namespaceId, namespaceName);
        }
    }

    /**
     * An implementation for {@link PrivateDnsNamespaceAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PrivateDnsNamespaceAttributes {
        private final java.lang.String namespaceArn;
        private final java.lang.String namespaceId;
        private final java.lang.String namespaceName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.namespaceArn = this.jsiiGet("namespaceArn", java.lang.String.class);
            this.namespaceId = this.jsiiGet("namespaceId", java.lang.String.class);
            this.namespaceName = this.jsiiGet("namespaceName", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String namespaceArn, final java.lang.String namespaceId, final java.lang.String namespaceName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.namespaceArn = java.util.Objects.requireNonNull(namespaceArn, "namespaceArn is required");
            this.namespaceId = java.util.Objects.requireNonNull(namespaceId, "namespaceId is required");
            this.namespaceName = java.util.Objects.requireNonNull(namespaceName, "namespaceName is required");
        }

        @Override
        public java.lang.String getNamespaceArn() {
            return this.namespaceArn;
        }

        @Override
        public java.lang.String getNamespaceId() {
            return this.namespaceId;
        }

        @Override
        public java.lang.String getNamespaceName() {
            return this.namespaceName;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("namespaceArn", om.valueToTree(this.getNamespaceArn()));
            data.set("namespaceId", om.valueToTree(this.getNamespaceId()));
            data.set("namespaceName", om.valueToTree(this.getNamespaceName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-servicediscovery.PrivateDnsNamespaceAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PrivateDnsNamespaceAttributes.Jsii$Proxy that = (PrivateDnsNamespaceAttributes.Jsii$Proxy) o;

            if (!namespaceArn.equals(that.namespaceArn)) return false;
            if (!namespaceId.equals(that.namespaceId)) return false;
            return this.namespaceName.equals(that.namespaceName);
        }

        @Override
        public int hashCode() {
            int result = this.namespaceArn.hashCode();
            result = 31 * result + (this.namespaceId.hashCode());
            result = 31 * result + (this.namespaceName.hashCode());
            return result;
        }
    }
}

==> servicediscovery-1.101.0-sources.jar: software/amazon/awscdk/services/servicediscovery/PrivateDnsNamespaceAttributes.java <==
package software.amazon.awscdk.services.servicediscovery;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:08:05.593Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicediscovery.$Module.class, fqn = "@aws-cdk/aws-servicediscovery.PrivateDnsNamespaceAttributes")
@software.amazon.jsii.Jsii.Proxy(PrivateDnsNamespaceAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface PrivateDnsNamespaceAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * Namespace ARN for the Namespace.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNamespaceArn();

    /**
     * Namespace Id for the Namespace.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNamespaceId();

    /**
     * A name for the Namespace.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getNamespaceName();

    /**
     * @return a {@link Builder} of {@link PrivateDnsNamespaceAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PrivateDnsNamespaceAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<PrivateDnsNamespaceAttributes> {
        private java.lang.String namespaceArn;
        private java.lang.String namespaceId;
        private java.lang.String namespaceName;

        /**
         * Sets the value of {@link PrivateDnsNamespaceAttributes#getNamespaceArn}
         * @param namespaceArn Namespace ARN for the Namespace. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder namespaceArn(java.lang.String namespaceArn) {
            this.namespaceArn = namespaceArn;
            return this;
        }

        /**
         * Sets the value of {@link PrivateDnsNamespaceAttributes#getNamespaceId}
         * @param namespaceId Namespace Id for the Namespace. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder namespaceId(java.lang.String namespaceId) {
            this.namespaceId = namespaceId;
            return this;
        }

        /**
         * Sets the value of {@link PrivateDnsNamespaceAttributes#getNamespaceName}
         * @param namespaceName A name for the Namespace. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder namespaceName(java.lang.String namespaceName) {
            this.namespaceName = namespaceName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PrivateDnsNamespaceAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public PrivateDnsNamespaceAttributes build() {
            return new Jsii$Proxy(namespaceArn, namespaceId, namespaceName);
        }
    }

    /**
     * An implementation for {@link PrivateDnsNamespaceAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PrivateDnsNamespaceAttributes {
        private final java.lang.String namespaceArn;
        private final java.lang.String namespaceId;
        private final java.lang.String namespaceName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.namespaceArn = software.amazon.jsii.Kernel.get(this, "namespaceArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.namespaceId = software.amazon.jsii.Kernel.get(this, "namespaceId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.namespaceName = software.amazon.jsii.Kernel.get(this, "namespaceName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String namespaceArn, final java.lang.String namespaceId, final java.lang.String namespaceName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.namespaceArn = java.util.Objects.requireNonNull(namespaceArn, "namespaceArn is required");
            this.namespaceId = java.util.Objects.requireNonNull(namespaceId, "namespaceId is required");
            this.namespaceName = java.util.Objects.requireNonNull(namespaceName, "namespaceName is required");
        }

        @Override
        public final java.lang.String getNamespaceArn() {
            return this.namespaceArn;
        }

        @Override
        public final java.lang.String getNamespaceId() {
            return this.namespaceId;
        }

        @Override
        public final java.lang.String getNamespaceName() {
            return this.namespaceName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("namespaceArn", om.valueToTree(this.getNamespaceArn()));
            data.set("namespaceId", om.valueToTree(this.getNamespaceId()));
            data.set("namespaceName", om.valueToTree(this.getNamespaceName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-servicediscovery.PrivateDnsNamespaceAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PrivateDnsNamespaceAttributes.Jsii$Proxy that = (PrivateDnsNamespaceAttributes.Jsii$Proxy) o;

            if (!namespaceArn.equals(that.namespaceArn)) return false;
            if (!namespaceId.equals(that.namespaceId)) return false;
            return this.namespaceName.equals(that.namespaceName);
        }

        @Override
        public final int hashCode() {
            int result = this.namespaceArn.hashCode();
            result = 31 * result + (this.namespaceId.hashCode());
            result = 31 * result + (this.namespaceName.hashCode());
            return result;
        }
    }
}
